@@ -66,7 +66,8 @@ if __name__ == '__main__':
                 editStr = ' '.join(irind.decode_edits(editList, 'str'))
                 # parse arguments in the file and store them in the target namespace
                 _args = parser.parse_args(editStr.split(), namespace)
-                print(f'edit file contains {len(serialized_edits)} edits, {len(_args.mutation_commands)} operations')
+                setattr(namespace, self.dest, values)
+                print(f'=== From {values}: {len(serialized_edits)} edits, {len(_args.mutation_commands)} operations ===')
 
     llvm_mutate_parser = argparse.ArgumentParser(description="Manipulate LLVM assembly from Nvidia CUDA Kernels")
     llvm_mutate_parser.add_argument('-o', '--output_file', metavar='FILE', type=FileOpener('w'), default='-',
@@ -74,7 +75,8 @@ if __name__ == '__main__':
     llvm_mutate_parser.add_argument('-f', '--input_file', metavar='FILE', type=FileOpener('r'), default='-',
         help='input file name. llvm-mutate will use and wait for stdin as the input stream if input file is not specified.')
     llvm_mutate_parser.add_argument('-ef', '--edit_file', metavar='FILE', action=LoadFromFile,
-        help='edit file name to feed edits instead of using commands. edit file contain edits under gevo format.')
+        help='edit file name to feed edits instead of using commands. edit file contain edits under gevo format. \
+              Note: edit_file enable not_use_result by default.')
     llvm_mutate_parser.add_argument('-n', '--name', action='store_true',
         help='add unique ID (UID) for each instruction. UID is one of needed instruction description in mutation operations')
     llvm_mutate_parser.add_argument('-I', '--ids', action='store_true',
@@ -121,10 +123,10 @@ if __name__ == '__main__':
 
     args = llvm_mutate_parser.parse_args()
     ret_code = RET_SUCCESS
-    OPT_NOT_USE_RESULT = '-use_result=0' if args.not_use_result else ''
 
-    if 'mutation_commands' and args.edit_file in args:
-        print("Warning: edit file will overwrite the mutation operations!")
+    if args.edit_file is not None:
+        args.not_use_result = True
+    OPT_NOT_USE_RESULT = '-use_result=0' if args.not_use_result else ''
 
     if args.name and 'mutation_commands' in args:
         print("--name and mutation operations cannot be used together.")
